==> phpnuke-5.5.tgz: www/phpnuke/html/modules/FAQ/language/lang-polish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_CATEGORY","Kategoria");
define("_CATEGORIES","Kategorie");
define("_FAQ2","FAQ (Czsto zadawane pytania)");
define("_BACKTOTOP","Powrt na gr");
define("_BACKTOFAQINDEX","Powrt do indeksu FAQ");
define("_MAIN","Gwna");
define("_QUESTION","Pytanie");
define("_ANSWER","Odpowied");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/FAQ/language/lang-polish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_CATEGORY","Kategoria");
define("_CATEGORIES","Kategorie");
define("_FAQ2","FAQ (Czsto zadawane pytania)");
define("_BACKTOTOP","Powrt na gr");
define("_BACKTOFAQINDEX","Powrt do indeksu FAQ");
define("_MAIN","Gwna");
define("_QUESTION","Pytanie");
define("_ANSWER","Odpowied");

?>
